@@ -1,14 +1,14 @@
 package Complete::Pod::Weaver;
 
-our $DATE = '2015-09-09'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-11-29'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 #use Log::Any '$log';
 
-use Complete::Setting;
+use Complete::Common qw(:all);
 
 our %SPEC;
 require Exporter;
@@ -20,24 +20,6 @@ our @EXPORT_OK = qw(
                        complete_weaver_role
                );
 
-my %common_args = (
-        word => {
-            schema => 'str*',
-            req => 1,
-            pos => 0,
-        },
-        ci => {
-            summary => 'Whether to do case-insensitive search',
-            schema  => 'bool*',
-        },
-        map_case => {
-            schema => 'bool',
-        },
-        exp_im_path => {
-            schema => 'bool',
-        },
-);
-
 $SPEC{':package'} = {
     v => 1.1,
     summary => 'Pod::Weaver-related completion routines',
@@ -47,7 +29,7 @@ $SPEC{complete_weaver_plugin} = {
     v => 1.1,
     summary => 'Complete with installed Pod::Weaver plugin names',
     args => {
-        %common_args,
+        %arg_word,
     },
     result_naked => 1,
 };
@@ -57,14 +39,10 @@ sub complete_weaver_plugin {
     my %args = @_;
 
     my $word = $args{word} // '';
-    my $ci          = $args{ci} // $Complete::Setting::OPT_CI;
-    my $map_case    = $args{map_case} // $Complete::Setting::OPT_MAP_CASE;
-    my $exp_im_path = $args{exp_im_path} // $Complete::Setting::OPT_EXP_IM_PATH;
 
     Complete::Module::complete_module(
         word => $word,
         ns_prefix => 'Pod::Weaver::Plugin',
-        ci=>$ci, map_case=>$map_case, exp_im_path=>$exp_im_path,
     );
 }
 
@@ -72,7 +50,7 @@ $SPEC{complete_weaver_section} = {
     v => 1.1,
     summary => 'Complete with installed Pod::Weaver::Section names',
     args => {
-        %common_args,
+        %arg_word,
     },
     result_naked => 1,
 };
@@ -82,14 +60,10 @@ sub complete_weaver_section {
     my %args = @_;
 
     my $word = $args{word} // '';
-    my $ci          = $args{ci} // $Complete::Setting::OPT_CI;
-    my $map_case    = $args{map_case} // $Complete::Setting::OPT_MAP_CASE;
-    my $exp_im_path = $args{exp_im_path} // $Complete::Setting::OPT_EXP_IM_PATH;
 
     Complete::Module::complete_module(
         word => $word,
         ns_prefix => 'Pod::Weaver::Section',
-        ci=>$ci, map_case=>$map_case, exp_im_path=>$exp_im_path,
     );
 }
 
@@ -97,7 +71,7 @@ $SPEC{complete_weaver_role} = {
     v => 1.1,
     summary => 'Complete with installed Pod::Weaver role names',
     args => {
-        %common_args,
+        %arg_word,
     },
     result_naked => 1,
 };
@@ -107,14 +81,10 @@ sub complete_weaver_role {
     my %args = @_;
 
     my $word = $args{word} // '';
-    my $ci          = $args{ci} // $Complete::Setting::OPT_CI;
-    my $map_case    = $args{map_case} // $Complete::Setting::OPT_MAP_CASE;
-    my $exp_im_path = $args{exp_im_path} // $Complete::Setting::OPT_EXP_IM_PATH;
 
     Complete::Module::complete_module(
         word => $word,
         ns_prefix => 'Pod::Weaver::Role',
-        ci=>$ci, map_case=>$map_case, exp_im_path=>$exp_im_path,
     );
 }
 
@@ -122,7 +92,7 @@ $SPEC{complete_weaver_bundle} = {
     v => 1.1,
     summary => 'Complete with installed Pod::Weaver bundle names',
     args => {
-        %common_args,
+        %arg_word,
     },
     result_naked => 1,
 };
@@ -132,14 +102,10 @@ sub complete_weaver_bundle {
     my %args = @_;
 
     my $word = $args{word} // '';
-    my $ci          = $args{ci} // $Complete::Setting::OPT_CI;
-    my $map_case    = $args{map_case} // $Complete::Setting::OPT_MAP_CASE;
-    my $exp_im_path = $args{exp_im_path} // $Complete::Setting::OPT_EXP_IM_PATH;
 
     Complete::Module::complete_module(
         word => $word,
         ns_prefix => 'Pod::Weaver::PluginBundle',
-        ci=>$ci, map_case=>$map_case, exp_im_path=>$exp_im_path,
     );
 }
 
@@ -158,7 +124,7 @@ Complete::Pod::Weaver - Pod::Weaver-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.04 of Complete::Pod::Weaver (from Perl distribution Complete-Pod-Weaver), released on 2015-09-09.
+This document describes version 0.05 of Complete::Pod::Weaver (from Perl distribution Complete-Pod-Weaver), released on 2015-11-29.
 
 =head1 SYNOPSIS
 
@@ -169,19 +135,15 @@ This document describes version 0.04 of Complete::Pod::Weaver (from Perl distrib
 
 Complete with installed Pod::Weaver bundle names.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
+=item * B<word>* => I<str> (default: "")
 
-Whether to do case-insensitive search.
-
-=item * B<exp_im_path> => I<bool>
-
-=item * B<map_case> => I<bool>
-
-=item * B<word>* => I<str>
+Word to complete.
 
 =back
 
@@ -192,19 +154,15 @@ Return value:  (any)
 
 Complete with installed Pod::Weaver plugin names.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
+=item * B<word>* => I<str> (default: "")
 
-Whether to do case-insensitive search.
-
-=item * B<exp_im_path> => I<bool>
-
-=item * B<map_case> => I<bool>
-
-=item * B<word>* => I<str>
+Word to complete.
 
 =back
 
@@ -215,19 +173,15 @@ Return value:  (any)
 
 Complete with installed Pod::Weaver role names.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
+=item * B<word>* => I<str> (default: "")
 
-Whether to do case-insensitive search.
-
-=item * B<exp_im_path> => I<bool>
-
-=item * B<map_case> => I<bool>
-
-=item * B<word>* => I<str>
+Word to complete.
 
 =back
 
@@ -238,19 +192,15 @@ Return value:  (any)
 
 Complete with installed Pod::Weaver::Section names.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
+=item * B<word>* => I<str> (default: "")
 
-Whether to do case-insensitive search.
-
-=item * B<exp_im_path> => I<bool>
-
-=item * B<map_case> => I<bool>
-
-=item * B<word>* => I<str>
+Word to complete.
 
 =back
 
